==> mx-cleanup_25.5.01.tar.xz: BUILD/translations/mx-cleanup_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="122"/>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>MX Cleanup</source>
        <translation>MX Pulizie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="666"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="638"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>Main</source>
        <translation>Principale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>Tools</source>
        <translation>Strumenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Removal Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="761"/>
        <source>Quit application</source>
        <translation>Esci dall&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Empty Trash</source>
        <translation>Svuota Cestino</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Trash older than:</source>
        <translation>Cestina i più vecchi di:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.ui" line="489"/>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> days</source>
        <translation>giorni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>All users</source>
        <translation>Tutti gli utenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>Selected user</source>
        <translation>Utente selezionato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="369"/>
        <source>Clear APT Cache</source>
        <translation>Pulisci la Cache di APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <source>Old files</source>
        <translation>Vecchi file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>All files</source>
        <translation>Tutti i file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="585"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Strumento grafico per Analizzare l&apos;Uso del Disco </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="597"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Avvia Disk Usage Analyzer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>Schedule</source>
        <translation>Programmazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>No automatic clean</source>
        <translation>Non pulizia automatica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>At reboot</source>
        <translation>Al riavvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>Daily</source>
        <translation>Quotidiana</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Weekly</source>
        <translation>Settimanale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Monthly</source>
        <translation>Mensile</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Free Disk Space for User</source>
        <translation>Spazio Libero, per l&apos;Utente, sul Disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Select user to repair</source>
        <translation>Seleziona un utente da riparare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Select user:</source>
        <translation>Seleziona utente:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Delete Logs</source>
        <translation>Elimina i file Log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>All logs</source>
        <translation>Tutti i log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>Old logs</source>
        <translation>Vecchi Log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Logs older than:</source>
        <translation>Registri più vecchi di:</translation>
    </message>
    <message>
        <source>Removal tool</source>
        <translation type="vanished">Strumento di rimozione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>Remove unused WiFi drivers</source>
        <translation>Rimuovi i driver WiFi inutilizzati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="550"/>
        <source>List and select kernels to remove</source>
        <translation>Elenca e seleziona i kernel da rimuovere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="36"/>
        <source>Clean Flatpak</source>
        <translation>Pulisci flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Remove unused runtimes</source>
        <translation>Rimuovi i runtime inutilizzati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Clean Folders</source>
        <translation>Cartelle da pulire</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Not accessed for:</source>
        <translation>Non acceduto per:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>All (potentially dangerous)</source>
        <translation>Tutto (potenzialmente pericoloso)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Thumbnails</source>
        <translation>Miniature</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Remove Manuals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>No manuals to remove.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Removing packages, please wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Press any key to close</source>
        <translation>Premi un tasto qualsiasi per chiudere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> day</source>
        <translation>giorno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Failed to elevate privileges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Cleanup script will run at reboot</source>
        <translation>Lo script di pulizia verrà eseguito al riavvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>Cleanup command done</source>
        <translation>Comando di Pulizia effettuato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB sono stati liberati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="580"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>Quick and safe removal of old files</source>
        <translation>Rimozione rapida e sicura dei vecchi file</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>%1 License</source>
        <translation>%1 Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="675"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Kernel attualmente in uso: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>Remove selected</source>
        <translation>Rimuovi selezionati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Kernel simili che possono essere rimossi:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="684"/>
        <source>Other kernels that can be removed:</source>
        <translation>Altri kernel che possono essere rimossi:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Niente da rimuovere.&lt;/b&gt; Impossibile rimuovere kernel in uso.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Quick safe removal of old files</source>
        <translation>Rimozione rapida sicura di vecchi file</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="87"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembra che tu sia loggato come root, fai il log out e poi il log in come utente normale per usare questo programma.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You must run this program with admin access.</source>
        <translation>Devi eseguire questo programma come amministratore.</translation>
    </message>
</context>
</TS>

==> mx-cleanup_25.6.03.tar.xz: BUILD/translations/mx-cleanup_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="122"/>
        <location filename="../mainwindow.cpp" line="682"/>
        <source>MX Cleanup</source>
        <translation>MX Pulizie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="683"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="692"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="658"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>Main</source>
        <translation>Principale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>Purge residual configurations from removed packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <source>Tools</source>
        <translation>Strumenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="545"/>
        <source>Removal Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="583"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>Rimuovi i manuali MX per lingue diverse da quella predefinita del sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="781"/>
        <source>Quit application</source>
        <translation>Esci dall&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="784"/>
        <location filename="../mainwindow.cpp" line="783"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="790"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="756"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="36"/>
        <source>Empty Trash</source>
        <translation>Svuota Cestino</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="45"/>
        <source>Trash older than:</source>
        <translation>Cestina i più vecchi di:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <location filename="../mainwindow.ui" line="294"/>
        <location filename="../mainwindow.ui" line="438"/>
        <location filename="../mainwindow.cpp" line="477"/>
        <source> days</source>
        <translation>giorni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>All users</source>
        <translation>Tutti gli utenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Selected user</source>
        <translation>Utente selezionato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Clear APT Cache</source>
        <translation>Pulisci la Cache di APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>Old files</source>
        <translation>Vecchi file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>All files</source>
        <translation>Tutti i file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="605"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Strumento grafico per Analizzare l&apos;Uso del Disco </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Avvia Disk Usage Analyzer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Schedule</source>
        <translation>Programmazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>No automatic clean</source>
        <translation>Non pulizia automatica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>At reboot</source>
        <translation>Al riavvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <source>Daily</source>
        <translation>Quotidiana</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>Weekly</source>
        <translation>Settimanale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Monthly</source>
        <translation>Mensile</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="467"/>
        <source>Free Disk Space for User</source>
        <translation>Spazio Libero, per l&apos;Utente, sul Disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <location filename="../mainwindow.ui" line="495"/>
        <source>Select user to repair</source>
        <translation>Seleziona un utente da riparare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>Select user:</source>
        <translation>Seleziona utente:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>Delete Logs</source>
        <translation>Elimina i file Log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <source>All logs</source>
        <translation>Tutti i log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <source>Old logs</source>
        <translation>Vecchi Log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>Logs older than:</source>
        <translation>Registri più vecchi di:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="551"/>
        <source>Remove unused WiFi drivers</source>
        <translation>Rimuovi i driver WiFi inutilizzati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="570"/>
        <source>List and select kernels to remove</source>
        <translation>Elenca e seleziona i kernel da rimuovere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Clean Flatpak</source>
        <translation>Pulisci flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <source>Remove unused runtimes</source>
        <translation>Rimuovi i runtime inutilizzati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Clean Folders</source>
        <translation>Cartelle da pulire</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Not accessed for:</source>
        <translation>Non acceduto per:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>All (potentially dangerous)</source>
        <translation>Tutto (potenzialmente pericoloso)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <source>Thumbnails</source>
        <translation>Miniature</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Remove Manuals</source>
        <translation>Rimuovi manuali</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>No manuals to remove.</source>
        <translation>Nessuno manuale da rimuovere.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Removing packages, please wait</source>
        <translation>Rimozione pacchetti, attendere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <location filename="../mainwindow.cpp" line="823"/>
        <source>Press any key to close</source>
        <translation>Premi un tasto qualsiasi per chiudere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="477"/>
        <source> day</source>
        <translation>giorno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>Failed to elevate privileges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="673"/>
        <source>Cleanup script will run at reboot</source>
        <translation>Lo script di pulizia verrà eseguito al riavvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Cleanup command done</source>
        <translation>Comando di Pulizia effettuato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB sono stati liberati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="682"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="685"/>
        <source>Quick and safe removal of old files</source>
        <translation>Rimozione rapida e sicura dei vecchi file</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="688"/>
        <source>%1 License</source>
        <translation>%1 Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="695"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="778"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Kernel attualmente in uso: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Remove selected</source>
        <translation>Rimuovi selezionati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="786"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Kernel simili che possono essere rimossi:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="787"/>
        <source>Other kernels that can be removed:</source>
        <translation>Altri kernel che possono essere rimossi:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="790"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Niente da rimuovere.&lt;/b&gt; Impossibile rimuovere kernel in uso.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Quick safe removal of old files</source>
        <translation>Rimozione rapida sicura di vecchi file</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="87"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembra che tu sia loggato come root, fai il log out e poi il log in come utente normale per usare questo programma.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You must run this program with admin access.</source>
        <translation>Devi eseguire questo programma come amministratore.</translation>
    </message>
</context>
</TS>
